@@ -12,6 +12,31 @@ import (
 	"github.com/matthewmueller/diff"
 )
 
+func TestNoActions(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// HTML response
+	res, err := app.Get("/")
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 404 Not Found
+		Content-Type: text/plain; charset=utf-8
+		X-Content-Type-Options: nosniff
+	`))
+	is.NoErr(app.Close())
+}
+
 func TestIndexString(t *testing.T) {
 	is := is.New(t)
 	ctx := context.Background()
@@ -1880,3 +1905,178 @@ func TestHandlerFuncs(t *testing.T) {
 	`)
 	is.NoErr(app.Close())
 }
+
+func TestEnvSupport(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		import "os"
+		type Controller struct {}
+		func (c *Controller) Index() string {
+			return os.Getenv("BUDDY")
+		}
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	cli.Env["BUDDY"] = "buddy"
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// Test GET /
+	res, err := app.Get("/")
+	is.NoErr(err)
+	res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"buddy"
+	`)
+	is.NoErr(app.Close())
+}
+
+func TestStructInStruct(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["model/post/post.go"] = `
+		package post
+		type Model struct {}
+	`
+	td.Files["controller/controller.go"] = `
+		package controller
+		import "context"
+		import "app.com/model/post"
+		type Controller struct {}
+		type Post struct {
+			Model post.Model
+		}
+		func (c *Controller) Show(ctx context.Context, id int) (post *Post, err error) {
+			return &Post{}, nil
+		}
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	result, err := cli.Run(ctx, "build")
+	is.NoErr(err)
+	is.Equal(result.Stdout(), "")
+	is.Equal(result.Stderr(), "")
+}
+
+// https://github.com/livebud/bud/issues/101
+func TestLoadController(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		func Load() (*Controller, error) {
+			return &Controller{}, nil
+		}
+		type Controller struct {}
+		func (c *Controller) Index() string { return "" }
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// Test GET /
+	res, err := app.Get("/")
+	is.NoErr(err)
+	res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		""
+	`)
+	is.NoErr(app.Close())
+}
+
+// https://github.com/livebud/bud/issues/135
+func TestSameNestedName(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/users/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Index() string { return "/users" }
+	`
+	td.Files["controller/admins/users/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Index() string { return "/admins/:id/users" }
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	res, err := app.Get("/users")
+	is.NoErr(err)
+	res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"/users"
+	`)
+	is.NoErr(app.Close())
+	res, err = app.Get("/admins/10/users")
+	is.NoErr(err)
+	res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"/admins/:id/users"
+	`)
+	is.NoErr(app.Close())
+}
+
+func TestControllerChange(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Index() (string, error) { return "/", nil }
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	res, err := app.GetJSON("/")
+	is.NoErr(err)
+	res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"/"
+	`)
+	// Update file
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Index() string { return "/" }
+	`
+	is.NoErr(td.Write(ctx))
+	is.NoErr(app.Ready(ctx))
+	// Try again with the new file
+	res, err = app.GetJSON("/")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"/"
+	`))
+	is.NoErr(app.Close())
+}
