@@ -412,13 +412,9 @@ func (l *loader) loadActionResultFields(result *parser.Result, def parser.Declar
 		l.Bail(fmt.Errorf("controller: unable to find struct for %s", result.Type()))
 	}
 	for _, field := range stct.PublicFields() {
-		def, err := field.Definition()
-		if err != nil {
-			l.Bail(fmt.Errorf("controller: unable to load definition for field %s in %s . %w", field.Name(), result.Name(), err))
-		}
 		fields = append(fields, &ActionResultField{
 			Name: field.Name(),
-			Type: l.loadType(field.Type(), def),
+			Type: field.Type().String(),
 		})
 	}
 	return fields
@@ -511,14 +507,16 @@ func (l *loader) loadContext(controller *Controller, method *parser.Function) *C
 	}
 	fnName := gotext.Camel("load " + controller.Name + " " + def.Name())
 	provider, err := l.injector.Wire(&di.Function{
-		Name:   fnName,
-		Target: l.module.Import("bud", "controller"),
-		Hoist:  true,
+		Name:    fnName,
+		Target:  l.module.Import("bud", "controller"),
+		Imports: l.imports,
+		Hoist:   true,
 		Results: []di.Dependency{
 			&di.Type{
 				Import: importPath,
 				Type:   recv.Type().String(),
 			},
+			&di.Error{},
 		},
 		Params: []di.Dependency{
 			di.ToType("net/http", "ResponseWriter"),
